dnl
dnl Copyright 1999-2008 University of Chicago
dnl Copyright 2008-2011 Nikhef, Amsterdam
dnl
dnl Licensed under the Apache License, Version 2.0 (the "License");
dnl you may not use this file except in compliance with the License.
dnl You may obtain a copy of the License at
dnl 
dnl     http://www.apache.org/licenses/LICENSE-2.0
dnl 
dnl Unless required by applicable law or agreed to in writing, software
dnl distributed under the License is distributed on an "AS IS" BASIS,
dnl WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
dnl See the License for the specific language governing permissions and
dnl limitations under the License.

# This module tests the presence of the gSOAP library and tools, see
# http://www.cs.fsu.edu/~engelen/soapmain.html

# Set an alternative directory to search for the gSOAP installation
AC_ARG_WITH(gsoap,
	[AC_HELP_STRING([--with-gsoap=DIR],
 	[Search for gsoap in DIR])],
 	[GSOAP_DIR=$withval],
 	[])


# AC_GSOAP([MINIMUM-VERSION])
# This macro test for gSOAP, and defines the following output variables:
# GSOAP_DIR - the base directory of the gSOAP installation
# gsoap_version - the version of gSOAP
# CPPFLAGS - additional flags for compilation against gSOAP
# LDFLAGS - additional flags for linking against gSOAP
AC_DEFUN_ONCE([AC_GSOAP],
[

    AC_PATH_PROG([WSDL2H], [wsdl2h], no, [$GSOAP_DIR/bin:$PATH])
    if test "$WSDL2H" = "no"; then
        AC_MSG_ERROR([Unable to locate gSOAP])
    fi
    AC_PATH_PROG([SOAPCPP2], [soapcpp2], no, [$GSOAP_DIR/bin:$PATH])
    if test "$SOAPCPP2" = "no"; then
        AC_MSG_ERROR([Unable to locate gSOAP])
    fi

    GSOAP_DIR="[`echo $SOAPCPP2 | sed -e s',/[^/]*/[^/]*$,,'`]"
    CPPFLAGS="$CPPFLAGS -I$GSOAP_DIR/include"
    LDFLAGS="$CPPFLAGS -L$GSOAP_DIR/lib -L$GSOAP_DIR/lib64"
    AC_CHECK_HEADER(stdsoap2.h, true, AC_MSG_ERROR(unable to find stdsoap2.h))

    gsoap_version=[`$SOAPCPP2 -v 2>&1 | sed -n 's/.*\([0-9][0-9]*\.[0-9][0-9]*\.[0-9][0-9]*\).*/\1/p'`]

dnl check if a minimum version is requested

    m4_if([$1],[],,
    [AS_VERSION_COMPARE([$gsoap_version],[$1],
	[AC_MSG_ERROR([Version $1 of gSOAP is required, but $gsoap_version was found.])],
	[], [])])
])# AC_GSOAP
